News for hackers. Stuff that matters.
Re:Clojure to Rust rewrite yields 17x speedup by augstein on Tuesday July 09, 2019 @02:44PM (#20395238)
From the comments:

„[…] the author confirms that Clojure solution uses boxed numbers.

Breaking news: boxed math is 17x slower than unboxed math in a computation-heavy task.„

Re:Clojure to Rust rewrite yields 17x speedup by cljuser on Tuesday July 09, 2019 @07:44PM (#20397912)
Clojure’s support for non boxed math is error prone and almost unusable. It’s support for non boxed collections is bolted on. Writing code like this in Clojure is a mess.